summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPageLayoutColumns.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoPageLayoutColumns.h')
-rw-r--r--lib/kofficeui/KoPageLayoutColumns.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kofficeui/KoPageLayoutColumns.h b/lib/kofficeui/KoPageLayoutColumns.h
index 09bad9d5..8ebac1b2 100644
--- a/lib/kofficeui/KoPageLayoutColumns.h
+++ b/lib/kofficeui/KoPageLayoutColumns.h
@@ -40,12 +40,12 @@ class KoPageLayoutColumns : public KoPageLayoutColumnsBase {
public:
/**
* Contructor
* @param tqparent the tqparent widget
* @param columns the KoColumns data structure that this dialog should be initialzed with
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param tqlayout the page tqlayout that the preview should be initialzed with.
*/
- KoPageLayoutColumns(TQWidget *tqparent, const KoColumns& columns, KoUnit::Unit unit, const KoPageLayout& tqlayout);
+ KoPageLayoutColumns(TQWidget *parent, const KoColumns& columns, KoUnit::Unit unit, const KoPageLayout& tqlayout);
/**
* Update the page preview widget with the param tqlayout.
@@ -40,12 +40,12 @@ class KoPageLayoutColumns : public KoPageLayoutColumnsBase {
/**
* Contructor
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @param columns the KoColumns data structure that this dialog should be initialzed with
* @param unit the unit-type (mm/cm/inch) that the dialog should show